@@ -1,6 +1,6 @@
 ############################################################################
 #
-# Copyright (c) 2001, 2002, 2004 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002, 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,7 +13,7 @@
 ############################################################################
 """Exported transaction functions.
 
-$Id: __init__.py 81644 2007-11-09 16:27:32Z chrism $
+$Id: __init__.py 112264 2010-05-12 20:36:53Z jim $
 """
 
 from transaction._transaction import Transaction
@@ -21,10 +21,12 @@ from transaction._manager import TransactionManager
 from transaction._manager import ThreadTransactionManager
 
 manager = ThreadTransactionManager()
-get = manager.get
+get = __enter__ = manager.get
 begin = manager.begin
 commit = manager.commit
 abort = manager.abort
+__exit__ = manager.__exit__
 doom = manager.doom
 isDoomed = manager.isDoomed
 savepoint = manager.savepoint
+attempts = manager.attempts
